==> okta-sdk-api-19.0.1-sources.jar: com/okta/sdk/resource/model/UserSchemaAttributeItems.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserSchemaAttributeEnum;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserSchemaAttributeItems
 */
@JsonPropertyOrder({ UserSchemaAttributeItems.JSON_PROPERTY_ENUM, UserSchemaAttributeItems.JSON_PROPERTY_ONE_OF,
        UserSchemaAttributeItems.JSON_PROPERTY_TYPE })
@javax.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2024-10-04T18:50:18.667445-05:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserSchemaAttributeItems implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ENUM = "enum";
    private List<String> _enum = null;

    public static final String JSON_PROPERTY_ONE_OF = "oneOf";
    private List<UserSchemaAttributeEnum> oneOf = null;

    public static final String JSON_PROPERTY_TYPE = "type";
    private String type;

    public UserSchemaAttributeItems() {
    }

    public UserSchemaAttributeItems _enum(List<String> _enum) {

        this._enum = _enum;
        return this;
    }

    public UserSchemaAttributeItems addenumItem(String _enumItem) {
        if (this._enum == null) {
            this._enum = new ArrayList<>();
        }
        this._enum.add(_enumItem);
        return this;
    }

    /**
     * Get _enum
     *
     * @return _enum
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENUM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getEnum() {
        return _enum;
    }

    @JsonProperty(JSON_PROPERTY_ENUM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEnum(List<String> _enum) {
        this._enum = _enum;
    }

    public UserSchemaAttributeItems oneOf(List<UserSchemaAttributeEnum> oneOf) {

        this.oneOf = oneOf;
        return this;
    }

    public UserSchemaAttributeItems addoneOfItem(UserSchemaAttributeEnum oneOfItem) {
        if (this.oneOf == null) {
            this.oneOf = new ArrayList<>();
        }
        this.oneOf.add(oneOfItem);
        return this;
    }

    /**
     * Get oneOf
     *
     * @return oneOf
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ONE_OF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<UserSchemaAttributeEnum> getOneOf() {
        return oneOf;
    }

    @JsonProperty(JSON_PROPERTY_ONE_OF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOneOf(List<UserSchemaAttributeEnum> oneOf) {
        this.oneOf = oneOf;
    }

    public UserSchemaAttributeItems type(String type) {

        this.type = type;
        return this;
    }

    /**
     * Get type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(String type) {
        this.type = type;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserSchemaAttributeItems userSchemaAttributeItems = (UserSchemaAttributeItems) o;
        return Objects.equals(this._enum, userSchemaAttributeItems._enum)
                && Objects.equals(this.oneOf, userSchemaAttributeItems.oneOf)
                && Objects.equals(this.type, userSchemaAttributeItems.type);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(_enum, oneOf, type);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserSchemaAttributeItems {\n");
        sb.append("    _enum: ").append(toIndentedString(_enum)).append("\n");
        sb.append("    oneOf: ").append(toIndentedString(oneOf)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-20.0.1-sources.jar: com/okta/sdk/resource/model/UserSchemaAttributeItems.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.UserSchemaAttributeEnum;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * UserSchemaAttributeItems
 */
@JsonPropertyOrder({ UserSchemaAttributeItems.JSON_PROPERTY_ENUM, UserSchemaAttributeItems.JSON_PROPERTY_ONE_OF,
        UserSchemaAttributeItems.JSON_PROPERTY_TYPE })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class UserSchemaAttributeItems implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ENUM = "enum";
    private List<String> _enum = null;

    public static final String JSON_PROPERTY_ONE_OF = "oneOf";
    private List<UserSchemaAttributeEnum> oneOf = null;

    public static final String JSON_PROPERTY_TYPE = "type";
    private String type;

    public UserSchemaAttributeItems() {
    }

    public UserSchemaAttributeItems _enum(List<String> _enum) {

        this._enum = _enum;
        return this;
    }

    public UserSchemaAttributeItems addenumItem(String _enumItem) {
        if (this._enum == null) {
            this._enum = new ArrayList<>();
        }
        this._enum.add(_enumItem);
        return this;
    }

    /**
     * Get _enum
     *
     * @return _enum
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ENUM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<String> getEnum() {
        return _enum;
    }

    @JsonProperty(JSON_PROPERTY_ENUM)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setEnum(List<String> _enum) {
        this._enum = _enum;
    }

    public UserSchemaAttributeItems oneOf(List<UserSchemaAttributeEnum> oneOf) {

        this.oneOf = oneOf;
        return this;
    }

    public UserSchemaAttributeItems addoneOfItem(UserSchemaAttributeEnum oneOfItem) {
        if (this.oneOf == null) {
            this.oneOf = new ArrayList<>();
        }
        this.oneOf.add(oneOfItem);
        return this;
    }

    /**
     * Get oneOf
     *
     * @return oneOf
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ONE_OF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<UserSchemaAttributeEnum> getOneOf() {
        return oneOf;
    }

    @JsonProperty(JSON_PROPERTY_ONE_OF)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setOneOf(List<UserSchemaAttributeEnum> oneOf) {
        this.oneOf = oneOf;
    }

    public UserSchemaAttributeItems type(String type) {

        this.type = type;
        return this;
    }

    /**
     * Get type
     *
     * @return type
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getType() {
        return type;
    }

    @JsonProperty(JSON_PROPERTY_TYPE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setType(String type) {
        this.type = type;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        UserSchemaAttributeItems userSchemaAttributeItems = (UserSchemaAttributeItems) o;
        return Objects.equals(this._enum, userSchemaAttributeItems._enum)
                && Objects.equals(this.oneOf, userSchemaAttributeItems.oneOf)
                && Objects.equals(this.type, userSchemaAttributeItems.type);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(_enum, oneOf, type);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class UserSchemaAttributeItems {\n");
        sb.append("    _enum: ").append(toIndentedString(_enum)).append("\n");
        sb.append("    oneOf: ").append(toIndentedString(oneOf)).append("\n");
        sb.append("    type: ").append(toIndentedString(type)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
